@@ -3,14 +3,14 @@ package Code::TidyAll::Git::Util;
 use strict;
 use warnings;
 
-use Code::TidyAll::Util qw(pushd);
+use File::pushd qw(pushd);
 use IPC::System::Simple qw(capturex);
 use List::SomeUtils qw(uniq);
 use Path::Tiny qw(path);
 
 use Exporter qw(import);
 
-our $VERSION = '0.61';
+our $VERSION = '0.62';
 
 our @EXPORT_OK = qw(git_files_to_commit git_modified_files);
 
