@@ -7,7 +7,7 @@ use Code::TidyAll::Util::Zglob qw(zglob_to_regex);
 sub test_match : Tests {
     my ( $zglob, $regex );
 
-    $zglob = "**/*.txt";
+    $zglob = '**/*.txt';
     $regex = zglob_to_regex($zglob);
     foreach my $path (qw(foo.txt foo/baz.txt foo/bar/baz.txt)) {
         like( $path, $regex, "$path matches $zglob" );
@@ -16,13 +16,13 @@ sub test_match : Tests {
         unlike( $path, $regex, "$path does not match $zglob" );
     }
 
-    $zglob = "**/*";
+    $zglob = '**/*';
     $regex = zglob_to_regex($zglob);
     foreach my $path (qw(foo foo.txt foo/bar foo/baz.txt)) {
         like( $path, $regex, "$path matches $zglob" );
     }
 
-    $zglob = "foo/**/*.txt";
+    $zglob = 'foo/**/*.txt';
     $regex = zglob_to_regex($zglob);
     foreach my $path (qw(foo/baz.txt foo/bar/baz.txt foo/bar/baz/blargh.txt)) {
         like( $path, $regex, "$path matches $zglob" );
